==> nextcloud-12.0.4.tar.bz2: nextcloud/apps/files_external/l10n/sk.js <==
OC.L10N.register(
    "files_external",
    {
    "External storages" : "Externé úložiská",
    "Personal" : "Osobné",
    "System" : "Systém",
    "Grant access" : "Povoliť prístup",
    "Error configuring OAuth1" : "Chyba konfigurovania OAuth1",
    "Please provide a valid app key and secret." : "Zadajte prosím platný aplikačný kľúč a heslo (secret).",
    "Error configuring OAuth2" : "Chyba konfigurovania OAuth2",
    "Generate keys" : "Vytvoriť kľúče",
    "Error generating key pair" : "Chyba pri vytváraní dvojice kľúčov",
    "All users. Type to select user or group." : "Všetci používatelia. Začnite písať pre výber používateľa alebo skupinu.",
    "(group)" : "(skupina)",
    "Compatibility with Mac NFD encoding (slow)" : "Kompatibilita s Mac NFD enkódovaním (pomalé)",
    "Admin defined" : "Nastavené správcom",
    "Are you sure you want to delete this external storage" : "Naozaj chcete zmazať toto externé úložisko?",
    "Delete storage?" : "Zmazať externé úložisko?",
    "Saved" : "Uložené",
    "Saving..." : "Ukladá sa...",
    "Save" : "Uložiť",
    "Empty response from the server" : "Prázdna odpoveď zo servera",
    "Couldn't access. Please log out and in again to activate this mount point" : "Nedá sa pripojiť. Pre aktiváciu tohto prípojného bodu sa prosím odhláste a znovu prihláste",
    "Couldn't get the information from the remote server: {code} {type}" : "Zo vzdialeného servera sa nedá získať informácia: {code} {type}",
    "Couldn't get the list of external mount points: {type}" : "Nedá sa získať zoznam externých prípojných bodov: {type}",
    "There was an error with message: " : "Nastala chyba s týmto hlásením:",
    "External mount error" : "Chyba externého úložiska",
    "external-storage" : "external-storage",
    "Couldn't fetch list of Windows network drive mount points: Empty response from server" : "Nedá sa získať zoznam sieťových úložísk systému Windows: prázdna odpoveď zo servera",
    "Some of the configured external mount points are not connected. Please click on the red row(s) for more information" : "Niektoré z nastavených externých úložísk nie sú pripojené. Pre viac informácií kliknite na červenú šípku(y)",
    "Please enter the credentials for the {mount} mount" : "Zadajte prosím prihlasovacie údaje k prípojnému bodu {mount}",
    "Username" : "Používateľské meno",
    "Password" : "Heslo",
    "Credentials saved" : "Prihlasovacie údaje uložené",
    "Credentials saving failed" : "Uloženie prihlasovacích údajov zlyhalo",
    "Credentials required" : "Vyžadované prihlasovacie údaje",
    "Storage with ID \"%d\" not found" : "Úložisko s ID \"%d\" sa nenašlo",
    "Invalid backend or authentication mechanism class" : "Neplatný backend, prípadne trieda mechanizmu autentifikácie",
    "Invalid mount point" : "Chybný prípojný bod",
    "Objectstore forbidden" : "Objectstore je zakáazaný",
    "Invalid storage backend \"%s\"" : "Neplatný backend úložiska \"%s\"",
    "Not permitted to use backend \"%s\"" : "Nie je povolené použiť backend \"%s\"",
    "Not permitted to use authentication mechanism \"%s\"" : "Nie je povolené použiť autentifikačný mechanizmus \"%s\"",
    "Unsatisfied backend parameters" : "Nedostatočné parametre backendu",
    "Unsatisfied authentication mechanism parameters" : "Nedostatočné parametre autentifikačného mechanizmu",
    "Insufficient data: %s" : "Nedostatočné dáta: %s",
    "%s" : "%s",
    "Storage with ID \"%d\" is not user editable" : "Úložisko s ID \"%d\" nie je upraviteľné používateľmi",
    "Access key" : "Prístupový kľúč",
    "Secret key" : "Tajný kľúč",
    "Builtin" : "Vstavaný",
    "None" : "Žiadny",
    "OAuth1" : "OAuth1",
    "App key" : "Kľúč aplikácie",
    "App secret" : "Heslo aplikácie",
    "OAuth2" : "OAuth2",
    "Client ID" : "Client ID",
    "Client secret" : "Heslo klienta",
    "OpenStack" : "OpenStack",
    "Tenant name" : "Meno nájomcu",
    "Identity endpoint URL" : "Endpoint URL identita",
    "Rackspace" : "Rackspace",
    "API key" : "API kľúč",
    "Global credentials" : "Globálne oprávnenia",
    "Log-in credentials, save in database" : "Prihlasovacie údaje, ukladať v databáze",
    "Username and password" : "Meno a heslo",
    "Log-in credentials, save in session" : "Prihlasovacie údaje, ukladať do relácie",
    "User entered, store in database" : "Používateľ zadaný, uložiť v databáze",
    "RSA public key" : "RSA verejný kľúč",
    "Public key" : "Verejný kľúč",
    "Amazon S3" : "Amazon S3",
    "Bucket" : "Sektor",
    "Hostname" : "Hostname",
    "Port" : "Port",
    "Region" : "Región",
    "Enable SSL" : "Povoliť SSL",
    "Enable Path Style" : "Povoliť štýl cesty",
    "WebDAV" : "WebDAV",
    "URL" : "URL",
    "Remote subfolder" : "Vzdialený podpriečinok",
    "Secure https://" : "Zabezpečené https://",
    "FTP" : "FTP",
    "Host" : "Hostiteľ",
    "Secure ftps://" : "Zabezpečené ftps://",
    "Local" : "Lokálny",
    "Location" : "Umiestnenie",
    "Nextcloud" : "Nextcloud",
    "SFTP" : "SFTP",
    "Root" : "Root",
    "SFTP with secret key login" : "SFTP prihlásenie s tajným kľúčom",
    "SMB / CIFS" : "SMB / CIFS",
    "Share" : "Sprístupniť",
    "Domain" : "Doména",
    "SMB / CIFS using OC login" : "SMB / CIFS s použitím OC prihlásenia",
    "Username as share" : "Používateľské meno ako sprístupnený priečinok",
    "OpenStack Object Storage" : "OpenStack Object Storage",
    "Service name" : "Názov služby",
    "Request timeout (seconds)" : "Timeout požiadavky (s)",
    "The cURL support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "Nie je povolená alebo nainštalovaná cURL podpora v PHP. Pripojenie %s nie je možné. Požiadajte svojho správcu, aby doplnil podporu.",
    "The FTP support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "Nie je povolená alebo nainštalovaná FTP podpora v PHP. Pripojenie %s nie je možné. Požiadajte svojho správcu, aby doplnil podporu.",
    "\"%s\" is not installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "Nie je nainštalované \"%s\". Pripojenie %s nie je možné. Požiadajte svojho správcu o inštaláciu.",
    "No external storage configured" : "Žiadne externé úložisko nie je nakonfigurované",
    "You can add external storages in the personal settings" : "Externé úložisko je možné pridať v osobných nastaveniach",
    "Name" : "Názov",
    "Storage type" : "Typ úložiska",
    "Scope" : "Rozsah",
    "Enable encryption" : "Povoliť šifrovanie",
    "Enable previews" : "Povoliť náhľady",
    "Enable sharing" : "Povoliť sprístupňovanie",
    "Check for changes" : "Zisťovať zmeny",
    "Never" : "Nikdy",
    "Once every direct access" : "S každým priamym prístupom",
    "Folder name" : "Názov priečinka",
    "External storage" : "Externé úložisko",
    "Authentication" : "Autentifikácia",
    "Configuration" : "Nastavenia",
    "Available for" : "K dispozícii pre",
    "Add storage" : "Pridať úložisko",
    "Advanced settings" : "Rozšírené nastavenia",
    "Delete" : "Zmazať",
    "Allow users to mount external storage" : "Povoliť používateľom pripojiť externé úložiská",
    "Allow users to mount the following external storage" : "Povoliť používateľom pripojiť tieto externé úložiská",
    "Fetching request tokens failed. Verify that your app key and secret are correct." : "Sťahovanie tokenov požiadavky zlyhalo. Overte prosím, či je aplikačný kľúč a heslo (secret) zadané správne.",
    "Fetching access tokens failed. Verify that your app key and secret are correct." : "Sťahovanie prístupových tokenov zlyhalo. Overte prosím, či je aplikačný kľúč a heslo (secret) zadané správne.",
    "Step 1 failed. Exception: %s" : "Krok 1 zlyhal. Výnimka: %s",
    "Step 2 failed. Exception: %s" : "Krok 2 zlyhal. Výnimka: %s",
    "Dropbox App Configuration" : "Nastavenie Dropbox aplikácie",
    "Google Drive App Configuration" : "Nastavenie Google Drive aplikácie",
    "Storage with id \"%i\" not found" : "Úložisko s ID \"%i\" sa nenašlo",
    "Storage with id \"%i\" is not user editable" : "Úložisko s id \"%i\" používatelia nemôžu upravovať",
    "Dropbox" : "Dropbox",
    "Google Drive" : "Google Drive"
},
"nplurals=3; plural=(n==1) ? 0 : (n>=2 && n<=4) ? 1 : 2;");

==> nextcloud-12.0.7.tar.bz2: nextcloud/apps/files_external/l10n/sk.js <==
OC.L10N.register(
    "files_external",
    {
    "External storages" : "Externé úložiská",
    "Personal" : "Osobné",
    "System" : "Systém",
    "Grant access" : "Povoliť prístup",
    "Error configuring OAuth1" : "Chyba konfigurovania OAuth1",
    "Please provide a valid app key and secret." : "Zadajte prosím platný aplikačný kľúč a heslo (secret).",
    "Error configuring OAuth2" : "Chyba konfigurovania OAuth2",
    "Generate keys" : "Vytvoriť kľúče",
    "Error generating key pair" : "Chyba pri vytváraní dvojice kľúčov",
    "All users. Type to select user or group." : "Všetci používatelia. Začnite písať pre výber používateľa alebo skupinu.",
    "(group)" : "(skupina)",
    "Compatibility with Mac NFD encoding (slow)" : "Kompatibilita s Mac NFD enkódovaním (pomalé)",
    "Admin defined" : "Nastavené správcom",
    "Delete storage?" : "Zmazať externé úložisko?",
    "Saved" : "Uložené",
    "Saving..." : "Ukladá sa...",
    "Save" : "Uložiť",
    "Empty response from the server" : "Prázdna odpoveď zo servera",
    "Couldn't access. Please log out and in again to activate this mount point" : "Nedá sa pripojiť. Pre aktiváciu tohto prípojného bodu sa prosím odhláste a znovu prihláste",
    "Couldn't get the information from the remote server: {code} {type}" : "Zo vzdialeného servera sa nedá získať informácia: {code} {type}",
    "Couldn't get the list of external mount points: {type}" : "Nedá sa získať zoznam externých prípojných bodov: {type}",
    "There was an error with message: " : "Nastala chyba s týmto hlásením:",
    "External mount error" : "Chyba externého úložiska",
    "external-storage" : "external-storage",
    "Couldn't fetch list of Windows network drive mount points: Empty response from server" : "Nedá sa získať zoznam sieťových úložísk systému Windows: prázdna odpoveď zo servera",
    "Some of the configured external mount points are not connected. Please click on the red row(s) for more information" : "Niektoré z nastavených externých úložísk nie sú pripojené. Pre viac informácií kliknite na červenú šípku(y)",
    "Please enter the credentials for the {mount} mount" : "Zadajte prosím prihlasovacie údaje k prípojnému bodu {mount}",
    "Username" : "Používateľské meno",
    "Password" : "Heslo",
    "Credentials saved" : "Prihlasovacie údaje uložené",
    "Credentials saving failed" : "Uloženie prihlasovacích údajov zlyhalo",
    "Credentials required" : "Vyžadované prihlasovacie údaje",
    "Storage with ID \"%d\" not found" : "Úložisko s ID \"%d\" sa nenašlo",
    "Invalid backend or authentication mechanism class" : "Neplatný backend, prípadne trieda mechanizmu autentifikácie",
    "Invalid mount point" : "Chybný prípojný bod",
    "Objectstore forbidden" : "Objectstore je zakáazaný",
    "Invalid storage backend \"%s\"" : "Neplatný backend úložiska \"%s\"",
    "Not permitted to use backend \"%s\"" : "Nie je povolené použiť backend \"%s\"",
    "Not permitted to use authentication mechanism \"%s\"" : "Nie je povolené použiť autentifikačný mechanizmus \"%s\"",
    "Unsatisfied backend parameters" : "Nedostatočné parametre backendu",
    "Unsatisfied authentication mechanism parameters" : "Nedostatočné parametre autentifikačného mechanizmu",
    "Insufficient data: %s" : "Nedostatočné dáta: %s",
    "%s" : "%s",
    "Storage with ID \"%d\" is not user editable" : "Úložisko s ID \"%d\" nie je upraviteľné používateľmi",
    "Access key" : "Prístupový kľúč",
    "Secret key" : "Tajný kľúč",
    "Builtin" : "Vstavaný",
    "None" : "Žiadny",
    "OAuth1" : "OAuth1",
    "App key" : "Kľúč aplikácie",
    "App secret" : "Heslo aplikácie",
    "OAuth2" : "OAuth2",
    "Client ID" : "Client ID",
    "Client secret" : "Heslo klienta",
    "OpenStack v2" : "OpenStack v2",
    "Tenant name" : "Meno nájomcu",
    "Identity endpoint URL" : "Endpoint URL identita",
    "OpenStack v3" : "OpenStack v3",
    "Domain" : "Doména",
    "Rackspace" : "Rackspace",
    "API key" : "API kľúč",
    "Global credentials" : "Globálne oprávnenia",
    "Log-in credentials, save in database" : "Prihlasovacie údaje, ukladať v databáze",
    "Username and password" : "Meno a heslo",
    "Log-in credentials, save in session" : "Prihlasovacie údaje, ukladať do relácie",
    "User entered, store in database" : "Používateľ zadaný, uložiť v databáze",
    "RSA public key" : "RSA verejný kľúč",
    "Public key" : "Verejný kľúč",
    "Amazon S3" : "Amazon S3",
    "Bucket" : "Sektor",
    "Hostname" : "Hostname",
    "Port" : "Port",
    "Region" : "Región",
    "Enable SSL" : "Povoliť SSL",
    "Enable Path Style" : "Povoliť štýl cesty",
    "WebDAV" : "WebDAV",
    "URL" : "URL",
    "Remote subfolder" : "Vzdialený podpriečinok",
    "Secure https://" : "Zabezpečené https://",
    "FTP" : "FTP",
    "Host" : "Hostiteľ",
    "Secure ftps://" : "Zabezpečené ftps://",
    "Local" : "Lokálny",
    "Location" : "Umiestnenie",
    "Nextcloud" : "Nextcloud",
    "SFTP" : "SFTP",
    "Root" : "Root",
    "SFTP with secret key login" : "SFTP prihlásenie s tajným kľúčom",
    "SMB / CIFS" : "SMB / CIFS",
    "Share" : "Sprístupniť",
    "SMB / CIFS using OC login" : "SMB / CIFS s použitím OC prihlásenia",
    "Username as share" : "Používateľské meno ako sprístupnený priečinok",
    "OpenStack Object Storage" : "OpenStack Object Storage",
    "Service name" : "Názov služby",
    "Request timeout (seconds)" : "Timeout požiadavky (s)",
    "The cURL support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "Nie je povolená alebo nainštalovaná cURL podpora v PHP. Pripojenie %s nie je možné. Požiadajte svojho správcu, aby doplnil podporu.",
    "The FTP support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "Nie je povolená alebo nainštalovaná FTP podpora v PHP. Pripojenie %s nie je možné. Požiadajte svojho správcu, aby doplnil podporu.",
    "\"%s\" is not installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "Nie je nainštalované \"%s\". Pripojenie %s nie je možné. Požiadajte svojho správcu o inštaláciu.",
    "External storage support" : "Podpora externého úložiska",
    "Name" : "Názov",
    "Storage type" : "Typ úložiska",
    "Scope" : "Rozsah",
    "Enable encryption" : "Povoliť šifrovanie",
    "Enable previews" : "Povoliť náhľady",
    "Enable sharing" : "Povoliť sprístupňovanie",
    "Check for changes" : "Zisťovať zmeny",
    "Never" : "Nikdy",
    "Once every direct access" : "S každým priamym prístupom",
    "Folder name" : "Názov priečinka",
    "External storage" : "Externé úložisko",
    "Authentication" : "Autentifikácia",
    "Configuration" : "Nastavenia",
    "Available for" : "K dispozícii pre",
    "Add storage" : "Pridať úložisko",
    "Advanced settings" : "Rozšírené nastavenia",
    "Delete" : "Zmazať",
    "Allow users to mount external storage" : "Povoliť používateľom pripojiť externé úložiská",
    "Allow users to mount the following external storage" : "Povoliť používateľom pripojiť tieto externé úložiská",
    "Step 1 failed. Exception: %s" : "Krok 1 zlyhal. Výnimka: %s",
    "Step 2 failed. Exception: %s" : "Krok 2 zlyhal. Výnimka: %s",
    "OpenStack" : "OpenStack",
    "Dropbox" : "Dropbox",
    "Google Drive" : "Google Drive",
    "No external storage configured" : "Žiadne externé úložisko nie je nakonfigurované",
    "You can add external storages in the personal settings" : "Externé úložisko je možné pridať v osobných nastaveniach",
    "Are you sure you want to delete this external storage" : "Naozaj chcete zmazať toto externé úložisko?"
},
"nplurals=3; plural=(n==1) ? 0 : (n>=2 && n<=4) ? 1 : 2;");
